@@ -256,7 +256,7 @@ void Profiler::CallPathStart(int tid)
         string *callpathname = TauFormulateNameString(this);
         DEBUGPROFMSG("Couldn't find string in map: "<<*comparison<<endl; );
 
-	string grname = string("TAU_CALLPATH | ") + string(ThisFunction->GetAllGroups());
+	string grname = string("TAU_CALLPATH | ") + RtsLayer::PrimaryGroup(ThisFunction->GetAllGroups());
   	CallPathFunction = new FunctionInfo(*callpathname, " ", 
 	  ThisFunction->GetProfileGroup(), (const char*) grname.c_str(), true );
 	TheCallPathMap().insert(map<TAU_CALLPATH_MAP_TYPE>::value_type(comparison, CallPathFunction));
@@ -325,7 +325,7 @@ void Profiler::CallPathStop(double TotalTime, int tid)
 }
   
 /***************************************************************************
- * $RCSfile: TauCallPath.cpp,v $   $Author: amorris $
- * $Revision: 1.18 $   $Date: 2005/05/20 20:42:29 $
- * TAU_VERSION_ID: $Id: TauCallPath.cpp,v 1.18 2005/05/20 20:42:29 amorris Exp $ 
+ * $RCSfile: TauCallPath.cpp,v $   $Author: sameer $
+ * $Revision: 1.20 $   $Date: 2005/08/11 02:10:42 $
+ * TAU_VERSION_ID: $Id: TauCallPath.cpp,v 1.20 2005/08/11 02:10:42 sameer Exp $ 
  ***************************************************************************/
