@@ -473,8 +473,218 @@ void TauUserEvent::ReportStatistics(bool ForEachThread)
   } // For all events
 }
 
+////////////////////////////////////////////////////////////////////////////
+// We now implement support for user defined events that link with callpaths
+////////////////////////////////////////////////////////////////////////////
+
+
+////////////////////////////////////////////////////////////////////////////
+// The datatypes and routines for maintaining a context map
+////////////////////////////////////////////////////////////////////////////
+#define TAU_CONTEXT_MAP_TYPE long *, TauUserEvent *, TaultUserEventLong
+
+/////////////////////////////////////////////////////////////////////////
+/* The comparison function for callpath requires the TaultUserEventLong struct
+ * to be defined. The operator() method in this struct compares two callpaths.
+ * Since it only compares two arrays of longs (containing addresses), we can
+ * look at the callpath depth as the first index in the two arrays and see if
+ * they're equal. If they two arrays have the same depth, then we iterate
+ * through the array and compare each array element till the end */
+/////////////////////////////////////////////////////////////////////////
+struct TaultUserEventLong
+{
+  bool operator() (const long *l1, const long *l2) const
+ {
+   int i;
+   /* first check 0th index (size) */
+   if (l1[0] != l2[0]) return (l1[0] < l2[0]);
+   /* they're equal, see the size and iterate */
+   for (i = 0; i < l1[0] ; i++)
+   {
+     if (l1[i] != l2[i]) return l1[i] < l2[i];
+   }
+   return (l1[i] < l2[i]);
+ }
+};
+
+
+/////////////////////////////////////////////////////////////////////////
+// We use one global map to store the callpath information
+/////////////////////////////////////////////////////////////////////////
+map<TAU_CONTEXT_MAP_TYPE >& TheContextMap(void)
+{ // to avoid initialization problems of non-local static variables
+  static map<TAU_CONTEXT_MAP_TYPE > contextmap;
+
+  return contextmap;
+}
+
+//////////////////////////////////////////////////////////////////////
+#define TAU_DEFAULT_CONTEXT_CALLPATH_DEPTH 2
+
+//////////////////////////////////////////////////////////////////////
+// How deep should the callpath be? The default value is 2
+//////////////////////////////////////////////////////////////////////
+int& TauGetContextCallPathDepth(void)
+{
+  char *depth;
+  static int value = 0;
+
+  
+  if (value == 0)
+  {
+    if ((depth = getenv("TAU_CALLPATH_DEPTH")) != NULL)
+    {
+      value = atoi(depth);
+      if (value > 1)
+      {
+        return value;
+      }
+      else
+      {
+        value = TAU_DEFAULT_CONTEXT_CALLPATH_DEPTH;
+        return value; /* default value */
+      }
+    }
+    else
+    {
+      value = TAU_DEFAULT_CONTEXT_CALLPATH_DEPTH;
+      return value;
+    }
+  }
+  else
+    return value;
+}
+
+
+    
+
+////////////////////////////////////////////////////////////////////////////
+// Formulate Context Comparison Array
+//////////////////////////////////////////////////////////////////////
+long* TauFormulateContextComparisonArray(Profiler *p)
+{
+  int depth = TauGetContextCallPathDepth();
+  /* Create a long array with size depth+1. We need to put the depth
+   * in it as the 0th index */
+  long *ary = new long [depth+1];
+
+  int i = 0;
+  int j;
+  Profiler *current = p; /* argument */
+
+  /* initialize the array */
+  for (j = 0; j < depth+1; j++)
+  {
+    ary[j] = 0L;
+  }
+  /* use the clean array now */
+
+  if (ary)
+  {
+    ary[0] = depth; /* this tells us how deep it is */
+    while (current != NULL && depth != 0)
+    {
+      i++; /* increment i */
+      ary[i] = (long) current->ThisFunction;
+      depth --;
+      current = current->ParentProfiler;
+    }
+  }
+  return ary;
+}
+
+////////////////////////////////////////////////////////////////////////////
+// Formulate Context Callpath name string
+////////////////////////////////////////////////////////////////////////////
+string * TauFormulateContextNameString(Profiler *p)
+{
+  DEBUGPROFMSG("Inside TauFormulateContextNameString()"<<endl;);
+  int depth = TauGetContextCallPathDepth();
+  Profiler *current = p;
+  string delimiter(" => ");
+  string *name = new string("");
+
+  while (current != NULL && depth != 0)
+  {
+    if (current != p)
+      *name =  current->ThisFunction->GetName() + string(" ") +
+               current->ThisFunction->GetType() + delimiter + *name;
+    else
+      *name =  current->ThisFunction->GetName() + string (" ") +
+               current->ThisFunction->GetType();
+    current = current->ParentProfiler;
+    depth --;
+  }
+  DEBUGPROFMSG("TauFormulateContextNameString:Name: "<<*name <<endl;);
+  return name;
+}
+
+
+
+////////////////////////////////////////////////////////////////////////////
+// Ctor for TauContextUserEvent 
+////////////////////////////////////////////////////////////////////////////
+TauContextUserEvent::TauContextUserEvent(const char *EName, bool MonoIncr)
+{
+  /* create the event */
+  uevent = new TauUserEvent(EName, MonoIncr);
+  DisableContext = false; /* context tracking is enabled by default */
+  MonotonicallyIncreasing = MonoIncr;
+}
+
+////////////////////////////////////////////////////////////////////////////
+// Dtor for TauContextUserEvent 
+////////////////////////////////////////////////////////////////////////////
+TauContextUserEvent::~TauContextUserEvent()
+{
+  delete uevent; 
+}
+
+////////////////////////////////////////////////////////////////////////////
+// SetDisableContext for TauContextUserEvent 
+////////////////////////////////////////////////////////////////////////////
+void TauContextUserEvent::SetDisableContext(bool value)
+{
+  /* set it */
+  DisableContext = value;
+}
+
+////////////////////////////////////////////////////////////////////////////
+// Trigger the context event
+////////////////////////////////////////////////////////////////////////////
+void TauContextUserEvent::TriggerEvent( TAU_EVENT_DATATYPE data, int tid)
+{
+  if (!DisableContext)
+  {
+    long *comparison = 0;
+    TauUserEvent *ue;
+    /* context tracking is enabled */
+    Profiler *current = Profiler::CurrentProfiler[tid];
+    comparison = TauFormulateContextComparisonArray(current); 
+
+    map<TAU_CONTEXT_MAP_TYPE>::iterator it = TheContextMap().find(comparison);
+    if (it == TheContextMap().end())
+    {
+      string contextname(uevent->EventName  + " : " + *TauFormulateContextNameString(current));
+      DEBUGPROFMSG("Couldn't find string in map: "<<*comparison<<endl; );
+      ue = new TauUserEvent((const char *)(contextname.c_str()), MonotonicallyIncreasing);
+      TheContextMap().insert(map<TAU_CONTEXT_MAP_TYPE>::value_type(comparison, ue));
+    }
+    else
+    {
+      /* found it! Get the user defined event from the map */
+      ue = (*it).second;
+      delete comparison; // free up memory when name is found
+    }
+    /* Now we trigger this event */
+    if (ue)
+     ue->TriggerEvent(data, tid);
+  }
+  uevent->TriggerEvent(data, tid);
+}
+
 /***************************************************************************
  * $RCSfile: UserEvent.cpp,v $   $Author: sameer $
- * $Revision: 1.15 $   $Date: 2004/10/09 00:29:55 $
- * POOMA_VERSION_ID: $Id: UserEvent.cpp,v 1.15 2004/10/09 00:29:55 sameer Exp $ 
+ * $Revision: 1.16 $   $Date: 2005/05/11 19:56:26 $
+ * POOMA_VERSION_ID: $Id: UserEvent.cpp,v 1.16 2005/05/11 19:56:26 sameer Exp $ 
  ***************************************************************************/
