@@ -340,17 +340,20 @@ int Ttf_ReadNumEvents( Ttf_FileHandleT fileHandle, Ttf_CallbacksT callbacks,
       if (eventDescr.Tag == TAU_MESSAGE_SEND_EVENT) 
       {
         /* send message */
-        /* In dynamic trace the format for par is
-           31 ..... 24 23 ......16 15..............0
-	   other       type          length
-	   So, mynode is the sender and its in GetNodeId(erec)
-	   SENDMSG <type> FROM <sender> TO <receiver> LEN <length>
-	*/
+        /* See RtsLayer::TraceSendMsg for documentation on the bit patterns of "parameter" */
+
+	x_uint64 xpar = parameter;
+
 	/* extract the information from the parameter */
-	msgTag   = (parameter>>16) & 0x000000FF;
-	otherNid = (parameter>>24) & 0x000000FF;
-	msgLen   =  parameter & 0x0000FFFF;
-        
+	msgTag   = ((xpar>>16) & 0x000000FF) | (((xpar >> 48) & 0xFF) << 8);
+	otherNid = ((xpar>>24) & 0x000000FF) | (((xpar >> 56) & 0xFF) << 8);
+	msgLen   = xpar & 0x0000FFFF | (xpar << 22 >> 54 << 16);
+	unsigned int comm = xpar << 16 >> 58;
+
+// 	printf ("sent tag = %d\n", msgTag);
+// 	printf ("sent comm = %d\n", comm);
+// 	printf ("sent msgLen = %d\n", msgLen);
+
 	/* If the application is multithreaded, insert call for matching sends/recvs here */
 	otherTid = 0;
 	if (*callbacks.SendMessage) 
@@ -363,16 +366,17 @@ int Ttf_ReadNumEvents( Ttf_FileHandleT fileHandle, Ttf_CallbacksT callbacks,
       { /* Check if it is a message receive operation */
         if (eventDescr.Tag == TAU_MESSAGE_RECV_EVENT)
 	{ 
-	/* In dynamic trace the format for par is
-	   31 ..... 24 23 ......16 15..............0
-	   other       type          length
-	   So, mynode is the receiver and its in GetNodeId(erec)
-	   RECVMSG <type> BY <receiver> FROM <sender> LEN <length>
-	*/
-	/* extract the information from the parameter */
-	  msgTag   = (parameter>>16) & 0x000000FF;
-	  otherNid = (parameter>>24) & 0x000000FF ;
-	  msgLen   =  parameter & 0x0000FFFF;
+
+        /* See RtsLayer::TraceSendMsg for documentation on the bit patterns of "parameter" */
+
+	  x_uint64 xpar = parameter;
+
+	  /* extract the information from the parameter */
+	  msgTag   = ((xpar>>16) & 0x000000FF) | (((xpar >> 48) & 0xFF) << 8);
+	  otherNid = ((xpar>>24) & 0x000000FF) | (((xpar >> 56) & 0xFF) << 8);
+	  msgLen   = xpar & 0x0000FFFF | (xpar << 22 >> 54 << 16);
+	  unsigned int comm = xpar << 16 >> 58;
+
 
 	  /* If the application is multithreaded, insert call for matching sends/recvs here */
 	  otherTid = 0;
@@ -583,6 +587,6 @@ int refreshTables(Ttf_fileT *tFile, Ttf_CallbacksT cb)
 }
 /***************************************************************************
  * $RCSfile: TAU_tf.cpp,v $   $Author: amorris $
- * $Revision: 1.8 $   $Date: 2005/06/14 18:13:13 $
- * TAU_VERSION_ID: $Id: TAU_tf.cpp,v 1.8 2005/06/14 18:13:13 amorris Exp $ 
+ * $Revision: 1.11 $   $Date: 2005/07/29 19:02:11 $
+ * TAU_VERSION_ID: $Id: TAU_tf.cpp,v 1.11 2005/07/29 19:02:11 amorris Exp $ 
  ***************************************************************************/
