@@ -18,7 +18,7 @@ import java.util.Vector;
  * the node, context and thread that identify the location, and the data collected for this
  * location, such as sample count, maximum value, minimum value, mean value and sum squared.  
  *
- * <P>CVS $Id: AtomicLocationProfile.java,v 1.5 2004/10/29 20:21:29 amorris Exp $</P>
+ * <P>CVS $Id: AtomicLocationProfile.java,v 1.6 2005/07/11 22:58:25 amorris Exp $</P>
  * @author	Kevin Huck, Robert Bell
  * @version	0.1
  * @since	0.1
@@ -276,7 +276,7 @@ public class AtomicLocationProfile {
 	buf.append("avg(p.standard_deviation), ");
 	buf.append("sum(p.sample_count), ");
 	buf.append("sum(p.maximum_value), sum(p.minimum_value), sum(p.mean_value), ");
-	buf.append("sum(p.sum_squared) ");
+	buf.append("sum(p.standard_deviation) ");
 	buf.append("from " + db.getSchemaPrefix() + "atomic_location_profile p ");
 	buf.append("inner join " + db.getSchemaPrefix() + "atomic_event e on e.id = p.atomic_event ");
 	buf.append(whereClause);
