@@ -8,9 +8,9 @@ import java.io.*;
  * UserEventProfiles as well as maximum data (e.g. max exclusive value for all functions on 
  * this thread). 
  *  
- * <P>CVS $Id: Thread.java,v 1.15 2005/03/08 00:55:54 amorris Exp $</P>
+ * <P>CVS $Id: Thread.java,v 1.18 2005/06/17 22:10:22 amorris Exp $</P>
  * @author	Robert Bell, Alan Morris
- * @version	$Revision: 1.15 $
+ * @version	$Revision: 1.18 $
  * @see		Node
  * @see		Context
  * @see		FunctionProfile
@@ -18,6 +18,19 @@ import java.io.*;
  */
 public class Thread implements Comparable {
 
+    private int nodeID = -1;
+    private int contextID = -1;
+    private int threadID = -1;
+    private List functionProfiles = new ArrayList();
+    private List userEventProfiles = new ArrayList();
+    private double[] doubleList;
+    private double maxNumCalls = 0;
+    private double maxNumSubr = 0;
+    private boolean trimmed = false;
+    private boolean relationsBuilt = false;
+    private int numMetrics = 0;
+    private static final int METRIC_SIZE = 6;
+    
     public Thread(int nodeID, int contextID, int threadID) {
         this(nodeID, contextID, threadID, 1);
     }
@@ -30,6 +43,16 @@ public class Thread implements Comparable {
         this.numMetrics = numMetrics;
     }
 
+    public String toString() {
+        if (nodeID == -1) {
+            return "Mean";
+        }
+        if (nodeID == -3) {
+            return "Standard Deviation";
+        }
+        return "n,c,t " + nodeID + "," + contextID + "," + threadID;
+    }
+    
     public int getNodeID() {
         return nodeID;
     }
@@ -59,19 +82,22 @@ public class Thread implements Comparable {
 
     public void addFunctionProfile(FunctionProfile fp) {
         int id = fp.getFunction().getID();
-        // increase the functionProfiles vector size if necessary
-        if (id >= functionProfiles.size()) {
-            functionProfiles.setSize(id + 1);
+        // increase the size of the functionProfiles list if necessary
+        while (id >= functionProfiles.size()) {
+            functionProfiles.add(null);
         }
+        
         functionProfiles.set(id, fp);
     }
 
     public void addUserEvent(UserEventProfile uep) {
         int id = uep.getUserEvent().getID();
         // increase the userEventProfiles vector size if necessary
-        if (id >= userEventProfiles.size()) {
-            userEventProfiles.setSize(id + 1);
+
+        while (id >= userEventProfiles.size()) {
+            userEventProfiles.add(null);
         }
+
         userEventProfiles.set(id, uep);
     }
 
@@ -81,28 +107,24 @@ public class Thread implements Comparable {
         return null;
     }
 
-    public Vector getFunctionProfiles() {
+    public List getFunctionProfiles() {
         return functionProfiles;
     }
 
     public Iterator getFunctionProfileIterator() {
-        return new DssIterator(functionProfiles);
+        return functionProfiles.iterator();
     }
 
     public UserEventProfile getUserEventProfile(UserEvent userEvent) {
         if ((userEventProfiles != null) && (userEvent.getID() < userEventProfiles.size()))
-            return (UserEventProfile) userEventProfiles.elementAt(userEvent.getID());
+            return (UserEventProfile) userEventProfiles.get(userEvent.getID());
         return null;
     }
 
-    public Vector getUserEventProfiles() {
+    public List getUserEventProfiles() {
         return userEventProfiles;
     }
 
-    public ListIterator getUsereventListIterator() {
-        return new DssIterator(userEventProfiles);
-    }
-
     private void setMaxInclusive(int metric, double inDouble) {
         this.insertDouble(metric, 0, inDouble);
     }
@@ -189,10 +211,10 @@ public class Thread implements Comparable {
         return threadID - ((Thread) obj).getThreadID();
     }
 
-    public String toString() {
-        return this.getClass().getName() + ": " + this.getNodeID() + "," + this.getContextID() + ","
-                + this.getThreadID();
-    }
+//    public String toString() {
+//        return this.getClass().getName() + ": " + this.getNodeID() + "," + this.getContextID() + ","
+//                + this.getThreadID();
+//    }
 
     public void setThreadData(int metric) {
         setThreadValues(metric, metric);
@@ -250,7 +272,7 @@ public class Thread implements Comparable {
 
                     // Note: Assumption is made that the max inclusive value is the value required to calculate
                     // percentage (ie, divide by). Thus, we are assuming that the sum of the exclusive
-                    // values is equal to the max inclusive value. This is a reasonable assuption. This also gets
+                    // values is equal to the max inclusive value. This is a reasonable assumption. This also gets
                     // us out of sticky situations when call path data is present (this skews attempts to calculate
                     // the total exclusive value unless checks are made to ensure that we do not include call path objects).
 
@@ -279,16 +301,5 @@ public class Thread implements Comparable {
         }
     }
 
-    private int nodeID = -1;
-    private int contextID = -1;
-    private int threadID = -1;
-    private Vector functionProfiles = new Vector();
-    private Vector userEventProfiles = new Vector();
-    private double[] doubleList;
-    private double maxNumCalls = 0;
-    private double maxNumSubr = 0;
-    private boolean trimmed = false;
-    private boolean relationsBuilt = false;
-    private int numMetrics = 0;
-    private static final int METRIC_SIZE = 6;
+    
 }
\ No newline at end of file
