@@ -17,9 +17,9 @@ import edu.uoregon.tau.paraprof.interfaces.*;
 /**
  * CallPathTextWindow: This window displays callpath data in a text format
  *   
- * <P>CVS $Id: CallPathTextWindow.java,v 1.26 2005/06/17 22:13:46 amorris Exp $</P>
+ * <P>CVS $Id: CallPathTextWindow.java,v 1.28 2005/08/10 21:48:04 amorris Exp $</P>
  * @author	Robert Bell, Alan Morris
- * @version	$Revision: 1.26 $
+ * @version	$Revision: 1.28 $
  * @see		CallPathDrawObject
  * @see		CallPathTextWindowPanel
  */
@@ -27,9 +27,6 @@ public class CallPathTextWindow extends JFrame implements ActionListener, MenuLi
         ScrollBarController, KeyListener, ParaProfWindow, UnitListener {
 
     private ParaProfTrial ppTrial = null;
-    private int nodeID = -1;
-    private int contextID = -1;
-    private int threadID = -1;
     private DataSorter dataSorter = null;
     private int windowType = 0; //0: mean data,1: function data, 2: global relations.
 
@@ -68,18 +65,18 @@ public class CallPathTextWindow extends JFrame implements ActionListener, MenuLi
         addKeyListener(this);
 
         //Now set the title.
-        if (windowType == 0) {
+        //if (windowType == 0) {
             if (thread.getNodeID() == -1) {
                 this.setTitle("Mean Call Path Data - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
             } else if (thread.getNodeID() == -3) {
                 this.setTitle("Standard Deviation Call Path Data - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
             } else {
-                this.setTitle("Call Path Data " + "n,c,t, " + nodeID + "," + contextID + "," + threadID + " - "
+                this.setTitle("Call Path Data " + "n,c,t, " + thread.getNodeID() + "," + thread.getContextID() + "," + thread.getThreadID() + " - "
                         + ppTrial.getTrialIdentifier(true));
             }
-        } else {
-            this.setTitle("Call Path Data Relations - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
-        }
+        //} else {
+        //    this.setTitle("Call Path Data Relations - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+       // }
 
         //Add some window listener code
         addWindowListener(new java.awt.event.WindowAdapter() {
