@@ -10,28 +10,27 @@
  * taken to ensure that DefaultMutableTreeNode references are cleaned when a node is collapsed.
 
  * 
- * <P>CVS $Id: ParaProfManagerWindow.java,v 1.23 2005/06/17 22:13:47 amorris Exp $</P>
+ * <P>CVS $Id: ParaProfManagerWindow.java,v 1.26 2005/07/12 18:26:56 amorris Exp $</P>
  * @author	Robert Bell, Alan Morris
- * @version	$Revision: 1.23 $
+ * @version	$Revision: 1.26 $
  * @see		ParaProfManagerTableModel
  */
 
 package edu.uoregon.tau.paraprof;
 
-import java.util.*;
 import java.awt.*;
 import java.awt.event.*;
-import java.io.*;
+import java.io.File;
+import java.io.PrintWriter;
+import java.io.StringWriter;
+import java.sql.SQLException;
+import java.util.*;
 
 import javax.swing.*;
 import javax.swing.event.*;
 import javax.swing.tree.*;
 
-import com.sun.rsasign.i;
-
 import edu.uoregon.tau.dms.dss.*;
-import edu.uoregon.tau.dms.database.*;
-import java.sql.SQLException;
 
 public class ParaProfManagerWindow extends JFrame implements ActionListener, TreeSelectionListener,
         TreeWillExpandListener {
@@ -684,7 +683,7 @@ public class ParaProfManagerWindow extends JFrame implements ActionListener, Tre
         if (databaseAPI != null) {
 
             boolean found = false;
-            ListIterator l = databaseAPI.getApplicationList();
+            ListIterator l = databaseAPI.getApplicationList().listIterator();
 
             while (l.hasNext()) {
                 ParaProfApplication dbApp = new ParaProfApplication((Application) l.next());
@@ -757,7 +756,7 @@ public class ParaProfManagerWindow extends JFrame implements ActionListener, Tre
 
         boolean found = false;
         databaseAPI.setApplication(dbApp);
-        ListIterator l = databaseAPI.getExperimentList();
+        ListIterator l = databaseAPI.getExperimentList().listIterator();
         while (l.hasNext()) {
             ParaProfExperiment dbExp = new ParaProfExperiment((Experiment) l.next());
 
@@ -962,7 +961,7 @@ public class ParaProfManagerWindow extends JFrame implements ActionListener, Tre
                     DatabaseAPI databaseAPI = this.getDatabaseAPI();
                     if (databaseAPI != null) {
 
-                        ListIterator l = databaseAPI.getApplicationList();
+                        ListIterator l = databaseAPI.getApplicationList().listIterator();
                         while (l.hasNext()) {
                             ParaProfApplication application = new ParaProfApplication((Application) l.next());
                             application.setDBApplication(true);
@@ -986,7 +985,7 @@ public class ParaProfManagerWindow extends JFrame implements ActionListener, Tre
                     DatabaseAPI databaseAPI = this.getDatabaseAPI();
                     if (databaseAPI != null) {
                         databaseAPI.setApplication(application.getID());
-                        ListIterator l = databaseAPI.getExperimentList();
+                        ListIterator l = databaseAPI.getExperimentList().listIterator();
                         while (l.hasNext()) {
                             ParaProfExperiment experiment = new ParaProfExperiment((Experiment) l.next());
                             experiment.setDBExperiment(true);
@@ -1023,7 +1022,7 @@ public class ParaProfManagerWindow extends JFrame implements ActionListener, Tre
                     DatabaseAPI databaseAPI = this.getDatabaseAPI();
                     if (databaseAPI != null) {
                         databaseAPI.setExperiment(experiment.getID());
-                        ListIterator l = databaseAPI.getTrialList();
+                        ListIterator l = databaseAPI.getTrialList().listIterator();
                         while (l.hasNext()) {
                             ParaProfTrial ppTrial = new ParaProfTrial((Trial) l.next());
                             ppTrial.setDBTrial(true);
@@ -1549,8 +1548,14 @@ public class ParaProfManagerWindow extends JFrame implements ActionListener, Tre
     //        return null;
     //    }
 
+    
+   // private DatabaseAPI dbAPI = null;
+    
     public DatabaseAPI getDatabaseAPI() {
 
+        //if (dbAPI != null) {
+       //     return dbAPI;
+       // }
         try {
             //Check to see if the user has set configuration information.
             if (ParaProf.preferences.getDatabaseConfigurationFile() == null) {
@@ -1558,12 +1563,18 @@ public class ParaProfManagerWindow extends JFrame implements ActionListener, Tre
                         "DB Configuration Error!", JOptionPane.ERROR_MESSAGE);
                 return null;
             } else {//Test to see if configurataion file exists.
-                File file = new File(ParaProf.preferences.getDatabaseConfigurationFile());
-                if (!file.exists()) {
-                    JOptionPane.showMessageDialog(this, "Specified configuration file does not exist.",
-                            "DB Configuration Error!", JOptionPane.ERROR_MESSAGE);
-                    return null;
-                }
+                
+                File file;
+               // if (ParaProf.JNLP) {
+                //    file = new File(new URI()ParaProf.class.getResource("/perfdmf.cfg")));
+                //} else {
+                    file = new File(ParaProf.preferences.getDatabaseConfigurationFile());
+               // }
+//                if (!file.exists()) {
+//                    JOptionPane.showMessageDialog(this, "Specified configuration file does not exist.",
+//                            "DB Configuration Error!", JOptionPane.ERROR_MESSAGE);
+//                    return null;
+//                }
             }
             //Basic checks done, try to access the db.
             DatabaseAPI databaseAPI = new DatabaseAPI();
@@ -1591,6 +1602,7 @@ public class ParaProfManagerWindow extends JFrame implements ActionListener, Tre
                 }
             }
 
+         //   dbAPI = databaseAPI;
             return databaseAPI;
         } catch (Exception e) {
             //Try and determine what went wrong, and then popup the help window
