@@ -33,7 +33,7 @@ public class ParaProfTrial implements ParaProfTreeNodeUserObject {
     private boolean loading = false;
 
     private SystemEvents systemEvents = new SystemEvents();
-    private FullDataWindow sMW = null;
+    private FullDataWindow fullDataWindow = null;
     private ColorChooser clrChooser = ParaProf.colorChooser;
     private PreferencesWindow preferencesWindow = ParaProf.preferencesWindow;
 
@@ -197,27 +197,25 @@ public class ParaProfTrial implements ParaProfTreeNodeUserObject {
     //Functions that control the obtaining and the opening
     //and closing of the static main window for this trial.
     //####################################
-    public FullDataWindow getStaticMainWindow() {
-        return sMW;
+    public FullDataWindow getFullDataWindow() {
+        return fullDataWindow;
     }
 
     public void showMainWindow() {
-        if (sMW == null) {
-            sMW = new FullDataWindow(this);
+        if (fullDataWindow == null) {
+            fullDataWindow = new FullDataWindow(this);
             ParaProf.incrementNumWindows();
-            sMW.setVisible(true);
-            this.getSystemEvents().addObserver(sMW);
+            fullDataWindow.setVisible(true);
         } else {
             ParaProf.incrementNumWindows();
-            this.getSystemEvents().addObserver(sMW);
-            sMW.show();
+            fullDataWindow.setVisible(true);
         }
     }
 
     public void closeStaticMainWindow() {
-        if (sMW != null) {
-            this.getSystemEvents().deleteObserver(sMW);
-            sMW.setVisible(false);
+        if (fullDataWindow != null) {
+            this.getSystemEvents().deleteObserver(fullDataWindow);
+            fullDataWindow.setVisible(false);
         }
     }
 
@@ -269,14 +267,10 @@ public class ParaProfTrial implements ParaProfTreeNodeUserObject {
     }
 
     //Override this function.
-    public Vector getMetrics() {
+    public List getMetrics() {
         return trial.getDataSource().getMetrics();
     }
 
-    public DssIterator getMetricList() {
-        return new DssIterator(this.getMetrics());
-    }
-
     public int getNumberOfMetrics() {
         return trial.getDataSource().getNumberOfMetrics();
     }
@@ -325,12 +319,12 @@ public class ParaProfTrial implements ParaProfTreeNodeUserObject {
     }
 
     public void setMeanData(int metricID) {
-        trial.getDataSource().setMeanData(metricID, metricID);
+        trial.getDataSource().generateStatistics(metricID, metricID);
     }
 
     // return a vector of only those functions that are currently "displayed" (i.e. group masks, etc)
-    public Vector getDisplayedFunctions() {
-        Vector displayedFunctions = new Vector();
+    public List getDisplayedFunctions() {
+        List displayedFunctions = new ArrayList();
 
         for (Iterator it = this.getDataSource().getFunctions(); it.hasNext();) {
             Function function = (Function) it.next();
@@ -402,9 +396,32 @@ public class ParaProfTrial implements ParaProfTreeNodeUserObject {
             ppMetrics.add(ppMetric);
         }
 
+        
         // Now set the dataSource's metrics.
         trial.getDataSource().setMetrics(ppMetrics);
 
+        
+        // Set the default metric to the first time based metric (if it exists)
+        for (int i = 0; i < numberOfMetrics; i++) {
+            ParaProfMetric ppMetric = (ParaProfMetric) trial.getDataSource().getMetric(i);
+            if (ppMetric.isTimeMetric()) {
+                setDefaultMetricID(i);
+                break;
+            }
+        }
+        
+
+        // Set the default metric to the first metric named "Time" (if it exists)
+        for (int i = 0; i < numberOfMetrics; i++) {
+            ParaProfMetric ppMetric = (ParaProfMetric) trial.getDataSource().getMetric(i);
+            if (ppMetric.getName().equalsIgnoreCase("Time")) {
+                setDefaultMetricID(i);
+                break;
+            }
+        }
+
+        
+        
         // set the colors
         clrChooser.setColors(this, -1);
 
