@@ -44,30 +44,10 @@ public class PreferencesWindow extends JFrame implements ActionListener, Observe
     JCheckBox showValuesAsPercentBox = new JCheckBox("Show Values as Percent");
     JCheckBox showPathTitleInReverseBox = new JCheckBox("Show Path Title in Reverse");
     JCheckBox reverseCallPathsBox = new JCheckBox("Reverse Call Paths");
+    JCheckBox meanIncludeNullBox = new JCheckBox("<html>Interpret threads that do not call a given function as a 0 value for statistics computation</html>");
     
     
-    void setControls() {
-        int tmpInt = fontComboBox.getItemCount();
-        int counter = 0;
-        //We should always have some fonts available, so this should be safe.
-        String tmpString = (String) fontComboBox.getItemAt(counter);
-        while ((counter < tmpInt) && (!(paraProfFont.equals(tmpString)))) {
-            counter++;
-            tmpString = (String) fontComboBox.getItemAt(counter);
-        }
 
-        if (counter == tmpInt) {
-            //The default font was not available. Indicate an error.
-            System.out.println("The default font was not found!  This is not a good thing as it is a default Java font!");
-        } else {
-            fontComboBox.setSelectedIndex(counter);
-        }
-
-        bold.setSelected((fontStyle == Font.BOLD) || (fontStyle == (Font.BOLD | Font.ITALIC)));
-        italic.setSelected((fontStyle == (Font.PLAIN | Font.ITALIC))
-                || (fontStyle == (Font.BOLD | Font.ITALIC)));
-        barHeightSlider.setValue(fontSize);
-    }
 
     public PreferencesWindow(Preferences preferences) {
         this.preferences = preferences;
@@ -79,6 +59,10 @@ public class PreferencesWindow extends JFrame implements ActionListener, Observe
         items[3] = "hr:mm:ss";
         unitsBox = new JComboBox(items); 
 
+        meanIncludeNullBox.setToolTipText("<html>There are two methods for computing the mean for a given function over all threads:<br>1. Add up the values for that function for each thread and divide by the total number of threads.<br>2. Add up the values for that function for each thread and divide by the number of threads that actually called that function.<br><br>This has the effect that if a particular function is only called by 2 threads:<br>The first method will show the mean value as 1/N where N is the total number of threads.<br>The second method will only divide by 2.<br><br>This option also affects standard deviation computation.");
+        reverseCallPathsBox.setToolTipText("<html>If this option is enabled, call path names will be shown in reverse<br>(e.g. \"C &lt;= B &lt;= A\" vs. \"A =&gt; B =&gt; C\")");
+        
+        
         if (preferences.getLoaded()) {
             // Set preferences based on saved values.
             paraProfFont = preferences.getParaProfFont();
@@ -88,8 +72,10 @@ public class PreferencesWindow extends JFrame implements ActionListener, Observe
             showValuesAsPercentBox.setSelected(preferences.getShowValuesAsPercent());
             showPathTitleInReverseBox.setSelected(preferences.getShowPathTitleInReverse());
             reverseCallPathsBox.setSelected(preferences.getReversedCallPaths());
+            meanIncludeNullBox.setSelected(!preferences.getComputeMeanWithoutNulls());
         }
 
+        //meanIncludeNullBox.setT
         //Add some window listener code
         addWindowListener(new java.awt.event.WindowAdapter() {
             public void windowClosing(java.awt.event.WindowEvent evt) {
@@ -111,7 +97,7 @@ public class PreferencesWindow extends JFrame implements ActionListener, Observe
         setTitle("ParaProf Preferences");
 
         int windowWidth = 550;
-        int windowHeight = 350;
+        int windowHeight = 400;
         setSize(new java.awt.Dimension(windowWidth, windowHeight));
 
         //There is really no need to resize this window.
@@ -194,10 +180,6 @@ public class PreferencesWindow extends JFrame implements ActionListener, Observe
         gbc.weighty = 0.25;
         ParaProfUtils.addCompItem(fontPanel, barHeightSlider, gbc, 1, 2, 1, 1);
 
-        
-        
-        
-        
 
 
 
@@ -219,8 +201,10 @@ public class PreferencesWindow extends JFrame implements ActionListener, Observe
         settingsPanel.setLayout(new GridBagLayout());
         ParaProfUtils.addCompItem(settingsPanel, showPathTitleInReverseBox, gbc, 0, 2, 2, 1);
         ParaProfUtils.addCompItem(settingsPanel, reverseCallPathsBox, gbc, 0, 3, 2, 1);
+        ParaProfUtils.addCompItem(settingsPanel, meanIncludeNullBox, gbc, 0, 4, 2, 1);
         
         
+        gbc.fill = GridBagConstraints.BOTH;
         
         addCompItem(fontPanel, gbc, 0, 0, 1, 1);
         addCompItem(defaultsPanel, gbc, 0, 1, 1, 1);
@@ -259,6 +243,29 @@ public class PreferencesWindow extends JFrame implements ActionListener, Observe
         setSavedPreferences();
 
     }
+    
+    void setControls() {
+        int tmpInt = fontComboBox.getItemCount();
+        int counter = 0;
+        //We should always have some fonts available, so this should be safe.
+        String tmpString = (String) fontComboBox.getItemAt(counter);
+        while ((counter < tmpInt) && (!(paraProfFont.equals(tmpString)))) {
+            counter++;
+            tmpString = (String) fontComboBox.getItemAt(counter);
+        }
+
+        if (counter == tmpInt) {
+            //The default font was not available. Indicate an error.
+            System.out.println("The default font was not found!  This is not a good thing as it is a default Java font!");
+        } else {
+            fontComboBox.setSelectedIndex(counter);
+        }
+
+        bold.setSelected((fontStyle == Font.BOLD) || (fontStyle == (Font.BOLD | Font.ITALIC)));
+        italic.setSelected((fontStyle == (Font.PLAIN | Font.ITALIC))
+                || (fontStyle == (Font.BOLD | Font.ITALIC)));
+        barHeightSlider.setValue(fontSize);
+    }
 
     private void setupMenus() {
         JMenuBar mainMenu = new JMenuBar();
@@ -327,6 +334,7 @@ public class PreferencesWindow extends JFrame implements ActionListener, Observe
         ParaProf.preferences.setShowValuesAsPercent(showValuesAsPercentBox.isSelected());
         ParaProf.preferences.setShowPathTitleInReverse(showPathTitleInReverseBox.isSelected());
         ParaProf.preferences.setReversedCallPaths(reverseCallPathsBox.isSelected());
+        ParaProf.preferences.setComputeMeanWithoutNulls(!meanIncludeNullBox.isSelected());
     }
 
     public boolean areBarDetailsSet() {
@@ -485,6 +493,7 @@ public class PreferencesWindow extends JFrame implements ActionListener, Observe
                     showValuesAsPercentBox.setSelected(true);
                     showPathTitleInReverseBox.setSelected(true);
                     reverseCallPathsBox.setSelected(false);
+                    meanIncludeNullBox.setSelected(true);
                     setControls();
                 }
 
@@ -500,8 +509,14 @@ public class PreferencesWindow extends JFrame implements ActionListener, Observe
             needDataEvent = true;
         }
         
+        if (meanIncludeNullBox.isSelected() == ParaProf.preferences.getComputeMeanWithoutNulls()) {
+            needDataEvent = true;
+            DataSource.setMeanIncludeNulls(meanIncludeNullBox.isSelected());
+            ParaProf.paraProfManagerWindow.recomputeStats();
+        }
+        
         setSavedPreferences();
-        Vector trials = ParaProf.paraProfManager.getLoadedTrials();
+        Vector trials = ParaProf.paraProfManagerWindow.getLoadedTrials();
         for (Iterator it = trials.iterator(); it.hasNext();) {
             ParaProfTrial ppTrial = (ParaProfTrial) it.next();
             ppTrial.getSystemEvents().updateRegisteredObjects("prefEvent");
