@@ -10,28 +10,25 @@
 package edu.uoregon.tau.paraprof;
 
 import java.awt.*;
-import java.awt.datatransfer.Clipboard;
-import java.awt.datatransfer.ClipboardOwner;
-import java.awt.datatransfer.Transferable;
-import java.awt.event.*;
+import java.awt.event.MouseEvent;
+import java.awt.event.MouseListener;
 import java.awt.font.*;
-import java.awt.geom.AffineTransform;
 import java.awt.print.PageFormat;
 import java.awt.print.Printable;
 import java.text.AttributedCharacterIterator;
 import java.text.AttributedString;
-import java.util.StringTokenizer;
-import java.util.Vector;
+import java.util.*;
+import java.util.List;
 
-import javax.swing.*;
+import javax.swing.JPanel;
+import javax.swing.JPopupMenu;
 
 import edu.uoregon.tau.dms.dss.Function;
 import edu.uoregon.tau.dms.dss.UtilFncs;
 import edu.uoregon.tau.paraprof.enums.ValueType;
-import edu.uoregon.tau.paraprof.interfaces.Searchable;
+import edu.uoregon.tau.paraprof.interfaces.ImageExport;
 
-public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProfImageInterface, MouseListener {
-    
+public class ThreadDataWindowPanel extends JPanel implements Printable, ImageExport, MouseListener {
 
     //Instance data.
     private int xPanelSize = 640;
@@ -48,13 +45,14 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
     private ParaProfTrial ppTrial = null;
     private ThreadDataWindow window = null;
     private edu.uoregon.tau.dms.dss.Thread thread = null;
-    private Vector list = new Vector();
+    private List list = new ArrayList();
 
     private int lastHeaderEndPosition = 0;
     private Searcher searcher;
+
     
-    public ThreadDataWindowPanel(ParaProfTrial trial, int nodeID, int contextID, int threadID,
-            ThreadDataWindow tDWindow) {
+    public ThreadDataWindowPanel(ParaProfTrial ppTrial, edu.uoregon.tau.dms.dss.Thread thread, ThreadDataWindow tDWindow) {
+        this.thread = thread;
         setSize(new java.awt.Dimension(xPanelSize, yPanelSize));
         setBackground(Color.white);
 
@@ -62,21 +60,15 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
         addMouseListener(searcher);
         addMouseMotionListener(searcher);
 
-        
         addMouseListener(this);
-        
-        this.ppTrial = trial;
+
+        this.ppTrial = ppTrial;
         this.window = tDWindow;
         barLength = baseBarLength;
 
         setAutoscrolls(true);
 
-        if (nodeID == -1) {
-            thread = trial.getDataSource().getMeanData();
-        } else {
-            thread = trial.getDataSource().getThread(nodeID, contextID, threadID);
-        }
-        
+
         //Schedule a repaint of this panel.
         repaint();
     }
@@ -84,7 +76,7 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
     public void paintComponent(Graphics g) {
         try {
             super.paintComponent(g);
-            renderIt((Graphics2D) g, true, false, false);
+            export((Graphics2D) g, true, false, false);
         } catch (Exception e) {
             ParaProfUtils.handleException(e);
             window.closeThisWindow();
@@ -98,7 +90,7 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
             }
 
             ParaProfUtils.scaleForPrint(g, pageFormat, xPanelSize, yPanelSize);
-            renderIt((Graphics2D) g, false, true, false);
+            export((Graphics2D) g, false, true, false);
 
             return Printable.PAGE_EXISTS;
         } catch (Exception e) {
@@ -116,24 +108,20 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
         if (searcher.getSearchLines() == null && list != null) {
             Vector searchLines = new Vector();
             for (int i = 0; i < list.size(); i++) {
-                PPFunctionProfile ppFunctionProfile = (PPFunctionProfile) list.elementAt(i);
+                PPFunctionProfile ppFunctionProfile = (PPFunctionProfile) list.get(i);
                 searchLines.add(ppFunctionProfile.getFunctionName());
             }
             searcher.setSearchLines(searchLines);
         }
     }
 
-    public void renderIt(Graphics2D g2D, boolean toScreen, boolean fullWindow, boolean drawHeader) {
+    public void export(Graphics2D g2D, boolean toScreen, boolean fullWindow, boolean drawHeader) {
         list = window.getData();
 
         //Some declarations.
-        double value = 0.0;
-        int stringWidth = 0;
-        int yCoord = 0;
         int barXCoord = barLength + textOffset;
         PPFunctionProfile ppFunctionProfile = null;
 
-        
         // With group support present, it is possible that the number of
         // functions in our data list is zero. This can occur when the user's selected
         // groups to display are not present on this thread ... for example. If so, just return.
@@ -150,7 +138,6 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
 
         searcher.setLineHeight(barSpacing);
 
-        
         //Obtain the font and its metrics.
         Font font = new Font(ppTrial.getPreferencesWindow().getParaProfFont(),
                 ppTrial.getPreferencesWindow().getFontStyle(), barHeight);
@@ -158,10 +145,10 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
         FontMetrics fmFont = g2D.getFontMetrics(font);
 
         searcher.setMaxDescent(fmFont.getMaxDescent());
-        
+
         if (maxRightSideStringPixelWidth == 0) {
             for (int i = 0; i < list.size(); i++) {
-                ppFunctionProfile = (PPFunctionProfile) list.elementAt(i);
+                ppFunctionProfile = (PPFunctionProfile) list.get(i);
                 maxRightSideStringPixelWidth = Math.max(maxRightSideStringPixelWidth,
                         fmFont.stringWidth(ppFunctionProfile.getFunctionName() + 5));
             }
@@ -172,16 +159,16 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
         //######
         //Set max values.
         //######
-        double maxValue = window.getDataSorter().getValueType().getThreadMaxValue(
-                window.getPPThread().getThread(), window.getDataSorter().getSelectedMetricID());
+        double maxValue = window.getDataSorter().getValueType().getThreadMaxValue(window.getPPThread().getThread(),
+                window.getDataSorter().getSelectedMetricID());
 
         // this is crap, this is not the correct way to determine the largest string, the largest
         // value item is not necessarily the longest as a string (variable width font)
         if (window.isPercent()) {
-            stringWidth = fmFont.stringWidth(UtilFncs.getOutputString(0, maxValue, 6) + "%");
+            int stringWidth = fmFont.stringWidth(UtilFncs.getOutputString(0, maxValue, 6) + "%");
             barXCoord = barXCoord + stringWidth;
         } else {
-            stringWidth = fmFont.stringWidth(UtilFncs.getOutputString(window.units(), maxValue,
+            int stringWidth = fmFont.stringWidth(UtilFncs.getOutputString(window.units(), maxValue,
                     ParaProf.defaultNumberPrecision));
             barXCoord = barXCoord + stringWidth;
         }
@@ -189,8 +176,12 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
         //End - Set max values.
         //######
 
+
+        int yCoord = 0;
+
         //determine which elements to draw (clipping)
-        int[] clips = ParaProfUtils.computeClipping(g2D.getClipBounds(), window.getViewRect(), toScreen, fullWindow, list.size(), barSpacing, yCoord);
+        int[] clips = ParaProfUtils.computeClipping(g2D.getClipBounds(), window.getViewRect(), toScreen, fullWindow,
+                list.size(), barSpacing, yCoord);
         int startElement = clips[0];
         int endElement = clips[1];
         yCoord = clips[2];
@@ -236,10 +227,10 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
 
         // Iterate through each function and draw it's bar
         for (int i = startElement; i <= endElement; i++) {
-            ppFunctionProfile = (PPFunctionProfile) list.elementAt(i);
+            ppFunctionProfile = (PPFunctionProfile) list.get(i);
 
             //value = ParaProfUtils.getValue(ppFunctionProfile, window.getValueType(), window.isPercent());
-            value = ppFunctionProfile.getValue();
+            double value = ppFunctionProfile.getValue();
 
             yCoord = yCoord + (barSpacing);
             drawBar(g2D, fmFont, maxValue, barXCoord, yCoord, barHeight, ppFunctionProfile, i, toScreen);
@@ -247,13 +238,13 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
 
     }
 
-    private void drawBar(Graphics2D g2D, FontMetrics fmFont, double maxValue, int barXCoord, int yCoord,
-            int barHeight, PPFunctionProfile ppFunctionProfile, int line, boolean toScreen) {
+    private void drawBar(Graphics2D g2D, FontMetrics fmFont, double maxValue, int barXCoord, int yCoord, int barHeight,
+            PPFunctionProfile ppFunctionProfile, int line, boolean toScreen) {
 
         double value = ppFunctionProfile.getValue();
         Function function = ppFunctionProfile.getFunction();
         String functionName = ppFunctionProfile.getFunctionName();
-        
+
         String originalFunctionName = functionName;
         boolean groupMember = ppFunctionProfile.isGroupMember(ppTrial.getHighlightedGroup());
 
@@ -294,7 +285,7 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
         //Do not want to put a percent sign after the bar if we are not doing exclusive or inclusive.
 
         String leftString;
-        
+
         if (window.getDataSorter().getValueType() == ValueType.EXCLUSIVE_PERCENT
                 || window.getDataSorter().getValueType() == ValueType.INCLUSIVE_PERCENT) {
             leftString = UtilFncs.getOutputString(0, value, 6) + "%";
@@ -312,22 +303,17 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
         int y = yCoord;
 
         searcher.drawHighlights(g2D, x, y, line);
-   
+
         // now draw the actual text
         g2D.setPaint(Color.black);
         g2D.drawString(functionName, x, y);
     }
-    
-    
-   
-        
 
     public void setBarLength(int barLength) {
         this.barLength = Math.max(1, barLength);
         this.repaint();
     }
 
-
     public void mouseClicked(MouseEvent evt) {
         try {
             //Get the location of the mouse.
@@ -343,11 +329,11 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
             int index = (yCoord) / (ppTrial.getPreferencesWindow().getBarSpacing());
 
             if (list != null && index < list.size()) {
-                ppFunctionProfile = (PPFunctionProfile) list.elementAt(index);
-                if ((evt.getModifiers() & InputEvent.BUTTON1_MASK) == 0) { // right click
-                    
-                    JPopupMenu popup = ParaProfUtils.createFunctionClickPopUp(ppTrial,
-                            ppFunctionProfile.getFunction(), this);
+                ppFunctionProfile = (PPFunctionProfile) list.get(index);
+                if (ParaProfUtils.rightClick(evt)) {
+
+                    JPopupMenu popup = ParaProfUtils.createFunctionClickPopUp(ppTrial, ppFunctionProfile.getFunction(),
+                            this);
                     popup.show(this, evt.getX(), evt.getY());
                     return;
                 } else { // not right click
@@ -359,23 +345,6 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
         }
     }
 
-
-    public void mouseReleased(MouseEvent evt) {
-    }
-
-    public void mouseEntered(MouseEvent evt) {
-    }
-
-    public void mouseExited(MouseEvent evt) {
-    }
-
-    public void mouseMoved(MouseEvent e) {
-    }
-
-    public void mouseDragged(MouseEvent evt) {
-
-    }
-
     public Dimension getImageSize(boolean fullScreen, boolean header) {
         Dimension d = null;
         if (fullScreen)
@@ -387,7 +356,7 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
     }
 
     //This method sets both xPanelSize and yPanelSize.
-    private boolean resizePanel(FontMetrics fmFont, int barXCoord, Vector list, int startElement, int endElement) {
+    private boolean resizePanel(FontMetrics fmFont, int barXCoord, List list, int startElement, int endElement) {
         boolean resized = false;
         int newXPanelSize = 0;
         int newYPanelSize = 0;
@@ -396,7 +365,7 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
         PPFunctionProfile ppFunctionProfile = null;
 
         for (int i = startElement; i <= endElement; i++) {
-            ppFunctionProfile = (PPFunctionProfile) list.elementAt(i);
+            ppFunctionProfile = (PPFunctionProfile) list.get(i);
             maxRightSideStringPixelWidth = Math.max(maxRightSideStringPixelWidth,
                     fmFont.stringWidth(ppFunctionProfile.getFunctionName() + 5));
         }
@@ -419,20 +388,26 @@ public class ThreadDataWindowPanel extends JPanel implements Printable, ParaProf
         return new Dimension(xPanelSize, (yPanelSize + 10));
     }
 
-   
-
-  
-
-
     public Searcher getSearcher() {
         return searcher;
     }
 
-    public void mousePressed(MouseEvent e) {
-        // TODO Auto-generated method stub
-        
+    public void mouseReleased(MouseEvent evt) {
     }
 
-    
+    public void mouseEntered(MouseEvent evt) {
+    }
+
+    public void mouseExited(MouseEvent evt) {
+    }
+
+    public void mouseMoved(MouseEvent e) {
+    }
+
+    public void mouseDragged(MouseEvent evt) {
+    }
+
+    public void mousePressed(MouseEvent e) {
+    }
 
 }
\ No newline at end of file
