@@ -11,7 +11,6 @@ import java.util.List;
 
 import javax.swing.*;
 
-import net.java.games.jogl.*;
 import edu.uoregon.tau.dms.dss.*;
 import edu.uoregon.tau.dms.dss.Thread;
 import edu.uoregon.tau.paraprof.enums.SortType;
@@ -19,14 +18,14 @@ import edu.uoregon.tau.paraprof.enums.ValueType;
 import edu.uoregon.tau.paraprof.enums.VisType;
 import edu.uoregon.tau.paraprof.interfaces.ParaProfWindow;
 import edu.uoregon.tau.paraprof.interfaces.UnitListener;
-import edu.uoregon.tau.paraprof.vis.*;
+import edu.uoregon.tau.vis.*;
 
 public class ThreeDeeWindow extends JFrame implements ActionListener, KeyListener, Observer, Printable, ParaProfWindow,
         UnitListener {
 
     private final int defaultToScatter = 4000;
 
-    private GLCanvas canvas;
+    private VisCanvas visCanvas;
     private VisRenderer visRenderer = new VisRenderer();
 
     private Plot plot;
@@ -44,8 +43,6 @@ public class ThreeDeeWindow extends JFrame implements ActionListener, KeyListene
 
     private JSplitPane jSplitPane;
 
-    private Animator animator;
-
     private TriangleMeshPlot triangleMeshPlot;
     private BarPlot barPlot;
     private ScatterPlot scatterPlot;
@@ -67,8 +64,13 @@ public class ThreeDeeWindow extends JFrame implements ActionListener, KeyListene
     float maxScatterValues[];
 
     public ThreeDeeWindow(ParaProfTrial ppTrial) {
+        // set the VisTools exception handler
+        VisTools.setSwingExceptionHandler(new ExceptionHandler() {
+            public void handleException(Exception e) {
+                ParaProfUtils.handleException(e);
+            }
+        });
         this.ppTrial = ppTrial;
-        ppTrial.getSystemEvents().addObserver(this);
 
         dataSorter = new DataSorter(ppTrial);
         dataSorter.setSortType(SortType.NAME);
@@ -94,13 +96,6 @@ public class ThreeDeeWindow extends JFrame implements ActionListener, KeyListene
             this.show();
         }
 
-        GLCapabilities glCapabilities = new GLCapabilities();
-
-        //glCapabilities.setHardwareAccelerated(true);
-
-        canvas = GLDrawableFactory.getFactory().createGLCanvas(glCapabilities);
-
-        canvas.setSize(200, 200);
 
         DataSource dataSource = ppTrial.getDataSource();
         int numThreads = dataSource.getNumThreads();
@@ -115,11 +110,9 @@ public class ThreeDeeWindow extends JFrame implements ActionListener, KeyListene
 
         visRenderer.addShape(plot);
         visRenderer.addShape(colorScale);
-        canvas.addGLEventListener(visRenderer);
+        visCanvas = new VisCanvas(visRenderer);
 
-        //canvas.addGLEventListener(new Gears.GearRenderer());
-
-        canvas.addKeyListener(this);
+        visCanvas.addKeyListener(this);
 
         JPanel panel = new JPanel() {
             public Dimension getMinimumSize() {
@@ -139,7 +132,7 @@ public class ThreeDeeWindow extends JFrame implements ActionListener, KeyListene
         gbc.gridy = 0;
         gbc.gridwidth = 1;
         gbc.gridheight = 1;
-        panel.add(canvas, gbc);
+        panel.add(visCanvas.getActualCanvas(), gbc);
         panel.setPreferredSize(new Dimension(5, 5));
 
         controlPanel = new ThreeDeeControlPanel(this, settings, ppTrial, visRenderer);
@@ -170,6 +163,7 @@ public class ThreeDeeWindow extends JFrame implements ActionListener, KeyListene
         }
 
         ParaProf.incrementNumWindows();
+        ppTrial.getSystemEvents().addObserver(this);
 
     }
 
@@ -406,14 +400,10 @@ public class ThreeDeeWindow extends JFrame implements ActionListener, KeyListene
             plot.setSelectedRow(newSettings.getSelections()[0]);
 
             if (newSettings.getVisType() == VisType.SCATTER_PLOT) {
-
                 visRenderer.setAim(settings.getScatterAim());
-                visRenderer.setEye(settings.getScatterEye());
-
             } else if (newSettings.getVisType() == VisType.TRIANGLE_MESH_PLOT
                     || newSettings.getVisType() == VisType.BAR_PLOT) {
                 visRenderer.setAim(settings.getRegularAim());
-                visRenderer.setEye(settings.getRegularEye());
             }
 
         } else {
@@ -606,7 +596,7 @@ public class ThreeDeeWindow extends JFrame implements ActionListener, KeyListene
                 return NO_SUCH_PAGE;
             }
 
-            ParaProfUtils.scaleForPrint(g, pageFormat, canvas.getWidth(), canvas.getHeight());
+            ParaProfUtils.scaleForPrint(g, pageFormat, visCanvas.getWidth(), visCanvas.getHeight());
 
             BufferedImage screenShot = visRenderer.createScreenShot();
 
