@@ -10,21 +10,45 @@
 
 package edu.uoregon.tau.paraprof;
 
-import java.util.*;
 import java.awt.*;
 import java.awt.event.*;
-import java.awt.print.*;
-import javax.swing.*;
-import java.awt.geom.*;
-import java.text.*;
 import java.awt.font.*;
-import edu.uoregon.tau.dms.dss.*;
+import java.awt.print.PageFormat;
+import java.awt.print.Printable;
+import java.text.AttributedCharacterIterator;
+import java.text.AttributedString;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.StringTokenizer;
+
+import javax.swing.*;
+
+import edu.uoregon.tau.dms.dss.UserEvent;
+import edu.uoregon.tau.dms.dss.UtilFncs;
+import edu.uoregon.tau.paraprof.interfaces.ImageExport;
 
 public class UserEventWindowPanel extends JPanel implements ActionListener, MouseListener, Printable,
-        ParaProfImageInterface {
+        ImageExport {
 
-    public UserEventWindowPanel(ParaProfTrial trial, UserEvent userEvent, UserEventWindow uEWindow) {
-        this.trial = trial;
+    private String counterName = null;
+    private UserEvent userEvent = null;
+    private int barHeight = -1;
+    private int barSpacing = -1;
+    private int baseBarLength = 250;
+    private int barLength = 0;
+    private int textOffset = 60;
+    private int maxXLength = 0;
+    private boolean groupMember = false;
+    private ParaProfTrial ppTrial = null;
+    private UserEventWindow window = null;
+    private List list = new ArrayList();
+    private int xPanelSize = 0;
+    private int yPanelSize = 0;
+    private JPopupMenu popup = new JPopupMenu();
+    private int lastHeaderEndPosition = 0;
+
+    public UserEventWindowPanel(ParaProfTrial ppTrial, UserEvent userEvent, UserEventWindow uEWindow) {
+        this.ppTrial = ppTrial;
         this.window = uEWindow;
         this.userEvent = userEvent;
         barLength = baseBarLength;
@@ -48,7 +72,7 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
     public void paintComponent(Graphics g) {
         try {
             super.paintComponent(g);
-            renderIt((Graphics2D) g, true, false, false);
+            export((Graphics2D) g, true, false, false);
         } catch (Exception e) {
             ParaProfUtils.handleException(e);
             window.closeThisWindow();
@@ -62,7 +86,7 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
             }
 
             ParaProfUtils.scaleForPrint(g, pageFormat, xPanelSize, yPanelSize);
-            renderIt((Graphics2D) g, false, true, false);
+            export((Graphics2D) g, false, true, false);
 
             return Printable.PAGE_EXISTS;
         } catch (Exception e) {
@@ -71,7 +95,7 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
         }
     }
 
-    public void renderIt(Graphics2D g2D, boolean toScreen, boolean fullWindow, boolean drawHeader) {
+    public void export(Graphics2D g2D, boolean toScreen, boolean fullWindow, boolean drawHeader) {
 
         list = window.getData();
 
@@ -85,15 +109,15 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
 
         //To make sure the bar details are set, this
         //method must be called.
-        trial.getPreferencesWindow().setBarDetails(g2D);
+        ppTrial.getPreferencesWindow().setBarDetails(g2D);
 
         //Now safe to grab spacing and bar heights.
-        barSpacing = trial.getPreferencesWindow().getBarSpacing();
-        barHeight = trial.getPreferencesWindow().getBarHeight();
+        barSpacing = ppTrial.getPreferencesWindow().getBarSpacing();
+        barHeight = ppTrial.getPreferencesWindow().getBarHeight();
 
         //Obtain the font and its metrics.
-        Font font = new Font(trial.getPreferencesWindow().getParaProfFont(),
-                trial.getPreferencesWindow().getFontStyle(), barHeight);
+        Font font = new Font(ppTrial.getPreferencesWindow().getParaProfFont(),
+                ppTrial.getPreferencesWindow().getFontStyle(), barHeight);
         g2D.setFont(font);
         FontMetrics fmFont = g2D.getFontMetrics(font);
 
@@ -151,7 +175,7 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
         //######
 
         for (int i = startElement; i <= endElement; i++) {
-            ppUserEventProfile = (PPUserEventProfile) list.elementAt(i);
+            ppUserEventProfile = (PPUserEventProfile) list.get(i);
 
             value = window.getValueType().getValue(ppUserEventProfile.getUserEventProfile());
 
@@ -183,8 +207,8 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
             g2D.setColor(userEvent.getColor());
             g2D.fillRect(barXCoord - xLength + 1, (yCoord - barHeight) + 1, xLength - 1, barHeight - 1);
 
-            if (userEvent == (trial.getHighlightedUserEvent())) {
-                g2D.setColor(trial.getColorChooser().getUserEventHighlightColor());
+            if (userEvent == (ppTrial.getHighlightedUserEvent())) {
+                g2D.setColor(ppTrial.getColorChooser().getUserEventHighlightColor());
                 g2D.drawRect(barXCoord - xLength, (yCoord - barHeight), xLength, barHeight);
                 g2D.drawRect(barXCoord - xLength + 1, (yCoord - barHeight) + 1, xLength - 2, barHeight - 2);
             } else {
@@ -192,8 +216,8 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
                 g2D.drawRect(barXCoord - xLength, (yCoord - barHeight), xLength, barHeight);
             }
         } else {
-            if (userEvent == (trial.getHighlightedUserEvent()))
-                g2D.setColor(trial.getColorChooser().getUserEventHighlightColor());
+            if (userEvent == (ppTrial.getHighlightedUserEvent()))
+                g2D.setColor(ppTrial.getColorChooser().getUserEventHighlightColor());
             else {
                 g2D.setColor(userEvent.getColor());
             }
@@ -228,11 +252,11 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
                     if (tmpCol != null) {
                         userEvent.setSpecificColor(tmpCol);
                         userEvent.setColorFlag(true);
-                        trial.getSystemEvents().updateRegisteredObjects("colorEvent");
+                        ppTrial.getSystemEvents().updateRegisteredObjects("colorEvent");
                     }
                 } else if (arg.equals("Reset to Generic Color")) {
                     userEvent.setColorFlag(false);
-                    trial.getSystemEvents().updateRegisteredObjects("colorEvent");
+                    ppTrial.getSystemEvents().updateRegisteredObjects("colorEvent");
                 }
             }
         } catch (Exception e) {
@@ -245,7 +269,7 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
         try {
             //For the moment, I am just showing the popup menu anywhere.
             //For a future release, there will be more here.
-            if ((evt.getModifiers() & InputEvent.BUTTON1_MASK) == 0) {
+            if (ParaProfUtils.rightClick(evt)) {
                 popup.show(this, evt.getX(), evt.getY());
             }
         } catch (Exception e) {
@@ -279,7 +303,7 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
     private boolean resizePanel(FontMetrics fmFont, int barXCoord) {
         boolean resized = false;
         int newYPanelSize = ((window.getData().size()) + 2) * barSpacing + 10;
-        int[] nct = trial.getMaxNCTNumbers();
+        int[] nct = ppTrial.getMaxNCTNumbers();
         String nctString = "n,c,t " + nct[0] + "," + nct[1] + "," + nct[2];
         ;
         int newXPanelSize = barXCoord + 5 + (fmFont.stringWidth(nctString)) + 25;
@@ -301,23 +325,4 @@ public class UserEventWindowPanel extends JPanel implements ActionListener, Mous
         this.repaint();
     }
 
-    private String counterName = null;
-
-    private UserEvent userEvent = null;
-    private int barHeight = -1;
-    private int barSpacing = -1;
-    private int baseBarLength = 250;
-    private int barLength = 0;
-    private int textOffset = 60;
-    private int maxXLength = 0;
-    private boolean groupMember = false;
-    private ParaProfTrial trial = null;
-    private UserEventWindow window = null;
-    private Vector list = new Vector();
-    int xPanelSize = 0;
-    int yPanelSize = 0;
-
-    private JPopupMenu popup = new JPopupMenu();
-
-    private int lastHeaderEndPosition = 0;
 }
\ No newline at end of file
