@@ -102,6 +102,7 @@ evalWithDebugMessage() {
 	echoIfVerbose "\n\nDebug: $2"
 	echoIfVerbose "Executing>  $1"
 	$1
+# NEVER add additional statements below $1, users of this function need the return code ($?)
 #	echoIfVerbose "....."
 }
 
@@ -426,6 +427,15 @@ for arg in "$@"
 			#-o is added later
 			;;
 
+		-o*)
+			hasAnOutputFile=$TRUE
+			passedOutputFile="${arg#"-o"}"
+			echoIfDebug "\tHas an output file = $passedOutputFile"
+			#With compilation, a new output file is created and is written with -o
+			#options, so no need to append it to argsRemaining. WIth
+			#others it is simply added to the command.
+			#-o is added later
+			;;
 
 		$CMD)
 			;;
@@ -623,6 +633,12 @@ if [ $gotoNextStep == $TRUE ]; then
 		  echoIfDebug "Not instrumenting source code. PDT not available."
 		fi
 
+		if [ $? -ne 0 ]; then
+			echoIfVerbose "Error: tau_instrumentor failed"
+			printError "$optTauInstr" "$tauCmd"
+			break
+		fi
+
 		echoIfDebug "Looking for tau file $tempInstFileName"
 		if [  ! -e $tempInstFileName ]; then
 			echoIfVerbose "Error: Tried Looking for file: $tempInstFileName"
@@ -730,6 +746,13 @@ if [ $gotoNextStep == $TRUE ]; then
 		if [ $hasAnOutputFile == $FALSE ]; then
 			passedOutputFile="a.out"
 		fi
+	
+		if [ $opari == $TRUE ]; then
+	  	  evalWithDebugMessage "/bin/rm -f opari.rc" "Removing opari.rc"
+	  	  cmdCompileOpariTab="${optTauCC} -c ${optIncludeDefs} opari.tab.c"
+		  evalWithDebugMessage "$cmdCompileOpariTab" "Compiling opari.tab.c"
+	  	  objectFilesForLinking="$objectFilesForLinking opari.tab.o"
+		fi
 
 		newCmd="$CMD  $argsRemaining $listOfObjectFiles $objectFilesForLinking $OUTPUTARGSFORTAU $optLinking -o $passedOutputFile"
 		evalWithDebugMessage "$newCmd" "Linking (Together) object files"
@@ -738,6 +761,10 @@ if [ $gotoNextStep == $TRUE ]; then
 			echoIfVerbose "Error: Tried Looking for file: $passedOutputFile"
 			printError "$CMD" "$newCmd"
 		fi
+	
+		if [ $opari == $TRUE -a $needToCleanPdbInstFiles == $TRUE ]; then
+	  	evalWithDebugMessage "/bin/rm -f opari.tab.c opari.tab.o *.opari.inc" "Removing opari.tab.c opari.tab.o *.opari.inc"
+		fi
 	fi
 
 fi
