@@ -19,6 +19,14 @@
 # include <sys/types.h>
 # include <fcntl.h>
 
+
+#ifdef TAU_LARGEFILE
+  #define LARGEFILE_OPTION O_LARGEFILE
+#else
+  #define LARGEFILE_OPTION 0
+#endif
+
+
 #ifdef TAU_NEC
 extern "C" {
 int getdtablesize(void);
@@ -405,7 +413,7 @@ int main(int argc, char *argv[])
   for (i=optind; i<argc-1; i++)
   {
     /* -- open input trace -------------------------------------------------- */
-    if ( (trcdes[numtrc].fd = open (argv[i], O_RDONLY | O_BINARY)) < 0 )
+    if ( (trcdes[numtrc].fd = open (argv[i], O_RDONLY | O_BINARY | LARGEFILE_OPTION )) < 0 )
     {
       perror (argv[i]);
       errflag = TRUE;
@@ -517,7 +525,7 @@ int main(int argc, char *argv[])
       fprintf (stderr, "%s exists; override [y]? ", trcfile);
       if ( getchar() == 'n' ) exit (1);
     }
-    if ( (outfd = open (trcfile, O_WRONLY|O_CREAT|O_TRUNC|O_BINARY, 0644)) < 0 )
+    if ( (outfd = open (trcfile, O_WRONLY|O_CREAT|O_TRUNC|O_BINARY| LARGEFILE_OPTION, 0644)) < 0 )
     {
       perror (trcfile);
       exit (1);
@@ -602,7 +610,7 @@ int main(int argc, char *argv[])
     /* -- if file was closed during the search for barriers, re-open it ----- */
     if ( trcdes[i].fd = -1 )
     {
-      if ( (trcdes[i].fd = open (trcdes[i].name, O_RDONLY|O_BINARY)) < 0 )
+      if ( (trcdes[i].fd = open (trcdes[i].name, O_RDONLY|O_BINARY| LARGEFILE_OPTION)) < 0 )
       {
         perror (argv[i]);
         exit (1);
